@@ -5,7 +5,7 @@ use warnings;
 package Ask;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.014';
+our $VERSION   = '0.015';
 
 use Carp qw(croak);
 use Moo::Role qw();
@@ -71,6 +71,12 @@ sub Q {
 	'Ask::Question'->new( @_ );
 }
 
+my $instance;
+sub instance {
+	shift;
+	@_ ? ( $instance = $_[0] ) : ( $instance ||= __PACKAGE__->detect );
+}
+
 1;
 
 __END__
@@ -117,6 +123,10 @@ to interact with the user.
 
 =over
 
+=item C<< Ask->instance >>
+
+Singleton pattern. Can also be passed an argument to use it as a setter.
+
 =item C<< Ask->detect(%arguments) >>
 
 A constructor, sort of. It inspects the program's environment and returns an
