@@ -5,7 +5,7 @@ use warnings;
 package Ask::Question;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.014';
+our $VERSION   = '0.015';
 
 use Moo;
 use Scalar::Util 'blessed';
@@ -30,7 +30,7 @@ has method   => ( is => 'rwp' );
 
 sub _build_backend {
 	require Ask;
-	'Ask'->detect;
+	'Ask'->instance;
 }
 
 sub BUILDARGS {
@@ -81,6 +81,10 @@ sub _build_coderef {
 			$local_default = $local_default->( @args );
 		}
 		
+		unless ( blessed($ask) and $ask->DOES('Ask::API') ) {
+			$ask = $ask->();
+		}
+		
 		my $local_type = $type;
 		if ( not ref $local_type ) {
 		
